Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon FinSpace.

Actions, resources, and condition keys for Amazon FinSpace - Service Authorization Reference

# Actions, resources, and condition keys for Amazon FinSpace

Amazon FinSpace (service prefix: `finspace` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by Amazon FinSpace
- Resource types defined by Amazon FinSpace
- Condition keys for Amazon FinSpace

## Actions defined by Amazon FinSpace

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

###### Note

Resource condition keys are listed in the Resource types table. You can find a link to the resource type that applies to an action in the Resource types (*required) column of the Actions table. The resource type in the Resource types table includes the Condition keys column, which are the resource condition keys that apply to an action in the Actions table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
ConnectKxCluster [permission only] | Grants permission to connect to a kdb cluster | Write | kxCluster* |  |
CreateEnvironment | Grants permission to create a FinSpace environment | Write | environment* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
CreateKxChangeset | Grants permission to create a changeset for a kdb database | Write | kxDatabase* |  |
CreateKxCluster | Grants permission to create a cluster in a managed kdb environment | Write | kxCluster* |  | ec2:DescribeSubnets finspace:MountKxDatabase
| aws:TagKeys aws:RequestTag/${TagKey} |
CreateKxDatabase | Grants permission to create a kdb database in a managed kdb environment | Write | kxDatabase* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
CreateKxEnvironment | Grants permission to create a managed kdb environment | Write |  | aws:TagKeys aws:RequestTag/${TagKey} |
CreateKxUser | Grants permission to create a user in a managed kdb environment | Write | kxEnvironment* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
CreateUser | Grants permission to create a FinSpace user | Write | environment* |  |
user* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
DeleteEnvironment | Grants permission to delete a FinSpace environment | Write | environment* |  |
DeleteKxCluster | Grants permission to delete a kdb cluster | Write | kxCluster* |  |
DeleteKxDatabase | Grants permission to delete a kdb database | Write | kxDatabase* |  |
DeleteKxEnvironment | Grants permission to delete a managed kdb environment | Write | kxEnvironment* |  |
DeleteKxUser | Grants permission to delete a kdb user | Write | kxUser* |  |
GetEnvironment | Grants permission to describe a FinSpace environment | Read | environment* |  |
GetKxChangeset | Grants permission to describe a changeset for a kdb database | Read | kxDatabase* |  |
GetKxCluster | Grants permission to describe a cluster in a managed kdb environment | Read | kxCluster* |  |
GetKxConnectionString | Grants permission to retrieve a connection string for kdb clusters | Read | kxCluster* |  | finspace:ConnectKxCluster
GetKxDatabase | Grants permission to describe a kdb database | Read | kxDatabase* |  |
GetKxEnvironment | Grants permission to describe a managed kdb environment | Read | kxEnvironment* |  |
GetKxUser | Grants permission to describe a kdb user | Read | kxUser* |  |
GetLoadSampleDataSetGroupIntoEnvironmentStatus | Grants permission to request status of the loading of sample data bundle | Read | environment* |  |
GetUser | Grants permission to describe a FinSpace user | Read | environment* |  |
user* |  |
ListEnvironments | Grants permission to list FinSpace environments in the AWS account | List | environment* |  |
ListKxChangesets | Grants permission to list changesets for a kdb database | List | kxDatabase* |  |
ListKxClusterNodes | Grants permission to list cluster nodes in a managed kdb environment | List | kxCluster* |  |
ListKxClusters | Grants permission to list clusters in a managed kdb environment | List | kxEnvironment* |  |
ListKxDatabases | Grants permission to list kdb databases in a managed kdb environment | List | kxEnvironment* |  |
ListKxEnvironments | Grants permission to list managed kdb environments | List |  |  |
ListKxUsers | Grants permission to list users in a managed kdb environment | List | kxEnvironment* |  |
ListTagsForResource | Grants permission to return a list of tags for a resource | List | environment* |  |
kxCluster* |  |
kxDatabase* |  |
kxEnvironment* |  |
kxUser* |  |
ListUsers | Grants permission to list FinSpace users in an environment | List | environment* |  |
user* |  |
LoadSampleDataSetGroupIntoEnvironment | Grants permission to load sample data bundle into your FinSpace environment | Write | environment* |  |
MountKxDatabase [permission only] | Grants permission to mount a database to a kdb cluster | Write | kxDatabase* |  |
ResetUserPassword | Grants permission to reset the password for a FinSpace user | Write | environment* |  |
user* |  |
TagResource | Grants permission to tag a resource | Tagging | environment |  |
kxCluster |  |
kxDatabase |  |
kxEnvironment |  |
kxUser |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
UntagResource | Grants permission to untag a resource | Tagging | environment |  |
kxCluster |  |
kxDatabase |  |
kxEnvironment |  |
kxUser |  |
| aws:TagKeys |
UpdateEnvironment | Grants permission to update a FinSpace environment | Write | environment* |  |
UpdateKxClusterDatabases | Grants permission to update databases for a cluster in a managed kdb environment | Write | kxCluster* |  |
UpdateKxDatabase | Grants permission to update a kdb database | Write | kxDatabase* |  |
UpdateKxEnvironment | Grants permission to update a managed kdb environment | Write | kxEnvironment* |  |
UpdateKxEnvironmentNetwork | Grants permission to update the network for a managed kdb environment | Write | kxEnvironment* |  |
UpdateKxUser | Grants permission to update a kdb user | Write | kxUser* |  |
UpdateUser | Grants permission to update a FinSpace user | Write | environment* |  |
user* |  |

## Resource types defined by Amazon FinSpace

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
environment | `arn:$ { Partition}:finspace:$ { Region}:$ { Account}:environment/$ { EnvironmentId}` | aws:ResourceTag/${TagKey}
user | `arn:$ { Partition}:finspace:$ { Region}:$ { Account}:user/$ { UserId}` | aws:ResourceTag/${TagKey}
kxEnvironment | `arn:$ { Partition}:finspace:$ { Region}:$ { Account}:kxEnvironment/$ { EnvironmentId}` | aws:ResourceTag/${TagKey}
kxUser | `arn:$ { Partition}:finspace:$ { Region}:$ { Account}:kxEnvironment/$ { EnvironmentId}/kxUser/$ { UserName}` | aws:ResourceTag/${TagKey}
kxCluster | `arn:$ { Partition}:finspace:$ { Region}:$ { Account}:kxEnvironment/$ { EnvironmentId}/kxCluster/$ { KxCluster}` | aws:ResourceTag/${TagKey}
kxDatabase | `arn:$ { Partition}:finspace:$ { Region}:$ { Account}:kxEnvironment/$ { EnvironmentId}/kxDatabase/$ { KxDatabase}` | aws:ResourceTag/${TagKey}

## Condition keys for Amazon FinSpace

Amazon FinSpace defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by the presence of tag key-value pairs in the request | String
aws:ResourceTag/${TagKey} | Filters access by the tag key-value pairs attached to the resource | String
aws:TagKeys | Filters access by the presence of tag keys in the request | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.